@@ -7,16 +7,36 @@ import json
 
 
 def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=True):
+    '''
+    Display an interactive quiz (currently multiple-choice or numeric answer)
+    using a mix of Python and Javascript to support use in rendered notebooks
+    (especially JupyterBook, but also Voila)
+
+    Inputs:
+    ref = string, reference to quiz JSON, may be:
+          - file name
+          - URL
+          - Python dict
+          - ID of HTML element with JSON as inner HTML
+          - ID of HTML element with base64-encoded JSON as inner HTML
+
+    shuffle_questions = boolean, whether to shuffle order of questions (default False)
+
+    shuffle_answers = boolean, whether to shuffle answers for multiple-choice questions (default True)
+
+    John  M. Shea
+    9/26/2021
+    '''
     resource_package = __name__
 
     letters = string.ascii_letters
     div_id = ''.join(random.choice(letters) for i in range(12))
-    # print(div_id)
+    #print(div_id)
 
-    mydiv = '<div id="' + div_id + '" data-shufflequestions="' + \
-        str(shuffle_questions) + '"'
-    mydiv += ' data-shuffleanswers="' + str(shuffle_answers) + '"'
-    mydiv += ' data-numquestions="' + str(num) + '">'
+    mydiv = f"""<div id="{div_id}" data-shufflequestions="{str(shuffle_questions)}"
+               data-shuffleanswers="{str(shuffle_answers)}"
+               data-numquestions="{str(num)}"> """
+    #print(mydiv)
 
     styles = "<style>"
     css = pkg_resources.resource_string(resource_package, "styles.css")
@@ -25,15 +45,28 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
 
     script = '<script type="text/Javascript">'
 
-    script += "questions"+div_id+"="
 
     if type(ref) == list:
         #print("List detected. Assuming JSON")
+        script += f"var questions{div_id}="
         script += json.dumps(ref)
         static = True
         url = ""
     elif type(ref) == str:
-        if ref.lower().find("http") == 0:
+        if ref[0] == '#':
+            script+=f'''var element=document.getElementById("{ref[1:]}");
+            var questions;
+            try {{
+               questions{div_id}=JSON.parse(window.atob(element.innerHTML));
+            }} catch(err) {{
+               console.log("Fell into catch");
+               questions{div_id} = JSON.parse(element.innerHTML);
+            }}
+            console.log(questions{div_id});'''
+            static = True;
+            #print(script)
+        elif ref.lower().find("http") == 0:
+            script += f"var questions{div_id}="
             url = ref
             file = urllib.request.urlopen(url)
             for line in file:
@@ -41,6 +74,7 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
             static = False
         else:
             #print("File detected")
+            script += f"var questions{div_id}="
             with open(ref) as file:
                 for line in file:
                     script += line
@@ -52,8 +86,6 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
     script += ''';
     '''
 
-    script += '//var mydiv=document.getElementById("testDIV");'
-    script += '//console.log(mydiv);'
 
     #display(HTML(mydiv + script))
     # return
@@ -74,44 +106,36 @@ def display_quiz(ref, num=1_000_000, shuffle_questions=False, shuffle_answers=Tr
     script += show_questions.decode("utf-8")
 
     if static:
-        script += '''
-        {
-        show_questions(questions'''
-        script_end = div_id+", "+div_id
-        script_end += ''');
-        }
+        script += f"""
+        {{
+        show_questions(questions{div_id},  {div_id});
+        }}
         </script>
-        '''
+        """
+        javascript = script 
+
 
-        javascript = script + script_end
         print()
     else:
-        script += '''
+        script += f'''
         //console.log(element);
-        {
+        {{
         const jmscontroller = new AbortController();
         const signal = jmscontroller.signal;
 
         setTimeout(() => jmscontroller.abort(), 5000);
 
-        fetch("'''
-        script_end = '''", {signal})
+        fetch("{url}", {{signal}})
         .then(response => response.json())
-        .then(json => show_questions(json, '''
-        # .then(json => console.log( '''
-
-        script_end += div_id
-        script_end += '''))
-        .catch(err => {
+        .then(json => show_questions(json, {div_id}))
+        .catch(err => {{
         console.log("Fetch error or timeout");
-        show_questions(questions'''
-        script_end += div_id+", "+div_id
-        script_end += ''');
-        });
-        }
+        show_questions(questions{div_id}, {div_id});
+        }});
+        }}
         </script>
         '''
-        javascript = script + url + script_end
+        javascript = script 
 
     # print(javascript)
     display(HTML(mydiv + styles + javascript))
